@@ -1,6 +1,8 @@
 # -*- coding: UTF-8 -*-
 from .dna import *
+from .gzipp import *
 from .html import *
+from .letters import *
 from .markdown import *
 from .url import *
 
